========================================================
EMDB-SFF Read/Write Toolkit (``sfftk-rw``)
========================================================

.. image:: https://img.shields.io/pypi/v/sfftk-rw?color=green
    :alt: PyPI

.. image:: https://img.shields.io/pypi/pyversions/sfftk-rw
    :alt: PyPI - Python Version

.. image:: https://travis-ci.org/emdb-empiar/sfftk-rw.svg?branch=master
    :target: https://travis-ci.org/emdb-empiar/sfftk-rw

.. image:: https://readthedocs.org/projects/sfftk-rw/badge/?version=latest
    :target: https://sfftk-rw.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://codecov.io/gh/emdb-empiar/sfftk-rw/branch/master/graph/badge.svg?token=OIN3VDFH1K
    :target: https://codecov.io/gh/emdb-empiar/sfftk-rw



-------------
About
-------------

``sfftk-rw`` is a Python toolkit for *reading and writing EMDB-SFF files only*. It is part of a family of tools
designed to work with EMDB-SFF files. Other related tools are:

-   ``sfftk`` - depends on ``sfftk-rw`` and additionally:

    *   **converts** application-specific segmentation files to valid EMDB-SFF files;

    *   **annotates** EMDB-SFF files;

    *   **prepares** segmentation files prior to conversion to EMDB-SFF files;

-   **SAT** - an online wrapper around ``sfftk`` available at https://www.ebi.ac.uk/empiar/sat/

-------------
License
-------------

``sfftk-rw`` is free and open source software released under the terms of the Apache License,
Version 2.0. Source code is copyright **EMBL-European Bioinformatics Institute (EMBL-EBI) 2017**.

